<h3>Introduction</h3>
<p>{{ name_app_title }} is a tool for documenting names used by the Libraries in its various digital library systems and collections.  The app provides a consistent way of communicating the authorized version of a name and information about the name that is useful for reuse.  {{ name_app_title }} generates a unique URL for each name that can be used to unambiguously refer to a person, organization, event, building or piece of software.  In addition to an HTML page for each name there are a number of other formats available for each record including a MADS XML version and a simple JSON representation.  A key feature of {{ name_app_title }} is the ability to link to other vocabularies such as the Virtual International Authority File (VIAF), the Library of Congress Name Authority File, or Wikipedia.  As time permits, the Libraries will integrate links into name records where appropriate.  A set of APIs are provided for integration of this application into other systems.  If you have questions or comments about {{ name_app_title }}, or if you would like a name added, please contact the Administrator{% if name_admin_email %} at <a href="{{ name_admin_email }}">{{ name_admin_email }}</a>{% endif %}.</p>

